@@ -32,6 +32,7 @@ if (!strcasecmp (buf,b)) \
 (*t) [b].adios_write_fn = adios_##a##_write; \
 (*t) [b].adios_get_write_buffer_fn = adios_##a##_get_write_buffer; \
 (*t) [b].adios_read_fn = adios_##a##_read; \
+(*t) [b].adios_buffer_overflow_fn = adios_##a##_buffer_overflow; \
 (*t) [b].adios_close_fn = adios_##a##_close; \
 (*t) [b].adios_finalize_fn = adios_##a##_finalize; \
 (*t) [b].adios_end_iteration_fn = adios_##a##_end_iteration; \
@@ -113,7 +114,8 @@ void adios_init_transports (struct adios_transport_struct ** t)
 # endif
 
     ASSIGN_FNS(posix,ADIOS_METHOD_POSIX,"POSIX")
-    ASSIGN_FNS(posix1,ADIOS_METHOD_POSIX1,"POSIX1")
+    // POSIX1 removed, POSIX with MPI_COMM_NULL does the same
+    //ASSIGN_FNS(posix1,ADIOS_METHOD_POSIX1,"POSIX1") 
 
 #  ifndef NO_RESEARCH_TRANSPORTS
     //ASSIGN_FNS(provenance,ADIOS_METHOD_PROVENANCE)
@@ -155,7 +157,8 @@ int adios_parse_method (const char * buf, enum ADIOS_IO_METHOD * method
 #endif
 
     MATCH_STRING_TO_METHOD("POSIX",ADIOS_METHOD_POSIX,0)
-    MATCH_STRING_TO_METHOD("POSIX1",ADIOS_METHOD_POSIX1,0)
+    // POSIX1 removed, POSIX with MPI_COMM_NULL does the same
+    MATCH_STRING_TO_METHOD("POSIX1",ADIOS_METHOD_POSIX,0)
     MATCH_STRING_TO_METHOD("FB",ADIOS_METHOD_POSIX,0)
 
 #if HAVE_DATASPACES
