@@ -16,6 +16,7 @@
 #include "core/adios_transport_hooks.h"
 #include "core/futils.h"
 #include "core/globals.h"
+#include "core/buffer.h"
 #include "public/adios_error.h"
 #include "core/adios_logger.h"
 #include "core/adios_timing.h"
@@ -30,6 +31,7 @@ extern "C"  /* prevent C++ name mangling */
 #endif
 
 extern int adios_errno;
+extern struct adios_transport_struct * adios_transports;
 
 ///////////////////////////////////////////////////////////////////////////////
 void FC_FUNC_(adios_set_application_id, ADIOS_SET_APPLICATION_ID) (int *id, int * err)
@@ -53,6 +55,11 @@ void FC_FUNC_(adios_init, ADIOS_INIT) (const char * config, MPI_Fint * comm, int
     }
 }
 
+int FC_FUNC_(adios_is_initialized, ADIOS_IS_INITIALIZED) ()
+{
+    return (adios_transports != NULL);
+}
+
 ///////////////////////////////////////////////////////////////////////////////
 void FC_FUNC_(adios_init_noxml, ADIOS_INIT_LOCAL) (MPI_Fint * comm, int * err)
 {
@@ -73,6 +80,14 @@ void FC_FUNC_(adios_allocate_buffer, ADIOS_ALLOCATE_BUFFER) (int *sizeMB, int *
     *err = common_adios_allocate_buffer (1 /*NOW*/, *sizeMB);
 }
 
+///////////////////////////////////////////////////////////////////////////////
+void FC_FUNC_(adios_set_max_buffer_size, ADIOS_SET_MAX_BUFFER_SIZE) (int *max_buffer_size_MB)
+{
+    if (*max_buffer_size_MB > 0)
+        adios_databuffer_set_max_size ((uint64_t)*max_buffer_size_MB * 1024L * 1024L);
+}
+
+
 ///////////////////////////////////////////////////////////////////////////////
 void FC_FUNC_(adios_open, ADIOS_OPEN) 
     (int64_t * fd, const char * group_name, const char * name
@@ -340,9 +355,9 @@ void FC_FUNC_(adios_write, ADIOS_WRITE)
     }
 
     *err = common_adios_write (fd, v, var);
-    if (fd->mode != adios_mode_read)
+    if (!adios_errno && fd->mode != adios_mode_read)
     {
-        adios_copy_var_written (fd->group, v);
+        adios_copy_var_written (fd, v);
     }
 
     free (buf1);
@@ -462,7 +477,8 @@ void FC_FUNC_(adios_stop_calculation, ADIOS_STOP_CALCULATION) (int * err)
 ///////////////////////////////////////////////////////////////////////////////
 void FC_FUNC_(adios_close, ADIOS_CLOSE) (int64_t * fd_p, int * err)
 {
-    *err = common_adios_close (*fd_p);
+    struct adios_file_struct * fd = (struct adios_file_struct *) *fd_p;
+    *err = common_adios_close (fd);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -487,7 +503,7 @@ void FC_FUNC_(adios_timing_write_xml, ADIOS_TIMING_WRITE_XML) (int64_t * fd_p, c
 // group a list of vars into a composite group
 void FC_FUNC_(adios_declare_group, ADIOS_DECLARE_GROUP) 
     (int64_t * id, const char * name
-    ,const char * time_index, enum ADIOS_FLAG *stats
+    ,const char * time_index, enum ADIOS_STATISTICS_FLAG *stats
     ,int * err, int name_size, int time_index_size
     )
 {
@@ -498,8 +514,12 @@ void FC_FUNC_(adios_declare_group, ADIOS_DECLARE_GROUP)
     buf1 = futils_fstr_to_cstr (name, name_size);
     buf2 = futils_fstr_to_cstr (time_index, time_index_size);
 
+    enum ADIOS_STATISTICS_FLAG stat_flag = *stats;
+    if (stat_flag == adios_stat_no_do_not_use_this)
+        stat_flag = adios_stat_no;
+
     if (buf1 != 0 && buf2 != 0) {
-        int ret = adios_common_declare_group (id, buf1, adios_flag_yes, "", "", buf2, *stats);
+        int ret = adios_common_declare_group (id, buf1, adios_flag_yes, "", "", buf2, stat_flag);
         free (buf1);
         free (buf2);
         if (ret == 1) {
@@ -510,6 +530,26 @@ void FC_FUNC_(adios_declare_group, ADIOS_DECLARE_GROUP)
     *err = adios_errno;
 }
 
+int FC_FUNC_(adios_set_time_aggregation, ADIOS_SET_TIME_AGGREGATION)
+        (int64_t * group_id, int64_t * buffersize, int64_t * sync_group_id, int * err)
+{
+    adios_errno = err_no_error;
+    if (*group_id == 0) {
+        adios_error (err_invalid_group, "adios_set_time_aggregation() called with 0 argument\n");
+    }
+    else
+    {
+        struct adios_group_struct * g = (struct adios_group_struct *) *group_id;
+        struct adios_group_struct * sg = NULL;
+        if (*sync_group_id != 0)
+            sg = (struct adios_group_struct *) *sync_group_id;
+        uint64_t bufsize = (uint64_t) *buffersize;
+
+        adios_common_set_time_aggregation(g, bufsize, sg);
+    }
+    *err = adios_errno;
+}
+
 ///////////////////////////////////////////////////////////////////////////////
 // adios_common_define_var is in adios_internals.c
 // declare a single var as an entry in a group
@@ -618,7 +658,7 @@ void FC_FUNC_(adios_define_attribute, ADIOS_DEFINE_ATTRIBUTE)
 
 void FC_FUNC_(adios_define_attribute_byvalue, ADIOS_DEFINE_ATTRIBUTE_BYVALUE) 
     (int64_t * group, const char * name, const char * path, int * type, int * nelems, 
-     void * values, int * err, int name_size, int path_size)
+     const void * values, int * err, int name_size, int path_size)
 {
     char * buf1 = 0;
     char * buf2 = 0;
