@@ -33,6 +33,7 @@ extern "C" {
 // Only processes of the provided communicator can later participate
 // in any adios activity
 int adios_init (const char * config, MPI_Comm comm);
+int adios_is_initialized(void);
 
 int adios_finalize (int mype);
 
@@ -84,22 +85,32 @@ int adios_close (int64_t fd_p);
 // ADIOS No-XML API's
 int adios_init_noxml (MPI_Comm comm);
 
-// To allocate ADIOS buffer
+// To allocate ADIOS buffer OBSOLETE
 int adios_allocate_buffer (
         enum ADIOS_BUFFER_ALLOC_WHEN adios_buffer_alloc_when,
         uint64_t buffer_size
         );
 
+// To set maximum buffer size for each adios_open()...adios_close() operation.
+void adios_set_max_buffer_size (uint64_t max_buffer_size_MB);
+
 // To declare a ADIOS group
 int adios_declare_group (int64_t * id, 
                          const char * name,
                          const char * time_index, 
-                         enum ADIOS_FLAG stats
+                         enum ADIOS_STATISTICS_FLAG stats
                         );
 
 // To free a ADIOS group
 int adios_free_group (int64_t id);
 
+// To set time aggregation of a group output in a certain buffer size but
+// flush whenever the synced group is being output
+int adios_set_time_aggregation(int64_t groupid,
+                               uint64_t buffersize,
+                               int64_t syncgroupid
+                              );
+
 // To select a I/O method for a ADIOS group
 int adios_select_method (int64_t group, 
                          const char * method,
@@ -124,6 +135,14 @@ int64_t adios_define_var (int64_t group_id,
 // for the next output step.
 int adios_delete_vardefs (int64_t id);
 
+// Return the expected size (in bytes) of a defined variable.
+// It is simply the product of local dimensions and byte-size of type.
+// It works only if the variable is defined with numeric dimensions or
+// the dimension variables are already written with adios_write().
+// Input is id returned by adios_define_var().
+// Returns 0 on error, check adios_errno for error code
+uint64_t adios_expected_var_size (int64_t var_id);
+
 // To set the transform method for a variable just defined 
 // var_id is the value returned by adios_define_var
 // returns adios_errno (0=OK)
@@ -145,7 +164,7 @@ int adios_define_attribute_byvalue (int64_t group,
                             const char * path, 
                             enum ADIOS_DATATYPES type,
                             int  nelems,
-                            void * values
+                            const void * values
                            );
 
 int adios_delete_attrdefs (int64_t id);
@@ -252,6 +271,21 @@ int adios_define_mesh_unstructured (char * points,
                                     char * nspace,
                                     int64_t group_id,
                                     const char * name);
+
+
+typedef struct
+{
+    int nmethods; 		// number of available methods
+    char ** name;     	// array of transport method names
+} ADIOS_AVAILABLE_WRITE_METHODS;
+
+/* Provide the names of transport methods available in the running application
+ */
+ADIOS_AVAILABLE_WRITE_METHODS * adios_available_write_methods();
+
+void adios_available_write_methods_free (ADIOS_AVAILABLE_WRITE_METHODS *);
+
+
 #ifdef __cplusplus
 }
 #endif
