@@ -64,7 +64,11 @@ adios_datablock * adios_transform_bzip2_pg_reqgroup_completed(adios_transform_re
 {
     uint64_t compressed_size = (uint64_t)completed_pg_reqgroup->raw_var_length;
     void* compressed_data = completed_pg_reqgroup->subreqs->data;
-    
+
+    // empty chunk in process group
+    if(completed_pg_reqgroup->transform_metadata == NULL)
+        return NULL;
+
     uint64_t uncompressed_size_meta = *((uint64_t*)completed_pg_reqgroup->transform_metadata);
     char compress_ok = *((char*)(completed_pg_reqgroup->transform_metadata + sizeof(uint64_t)));
 
