@@ -206,9 +206,9 @@ static struct open_file *open_file_delete(const char *path, const char *name)
         if ((strcmp(path, of->fpath) == 0) && (strcmp(name, of->fname) == 0)) {
             if (DEBUG>3) printf("fpath(%s) fname(%s) matches search\n", of->fpath, of->fname);
             if (list_is_head(&open_file_list, elmt)) {
-                list_rem_next(&open_file_list, NULL, &of);
+                list_rem_next(&open_file_list, NULL, (void**)&of);
             } else {
-                list_rem_next(&open_file_list, prev, &of);
+                list_rem_next(&open_file_list, prev, (void**)&of);
             }
         }
         prev = elmt;
@@ -1333,7 +1333,7 @@ void adios_nc4_init(
 //    md->size       = 0;
 }
 
-enum ADIOS_FLAG adios_nc4_should_buffer(
+enum BUFFERING_STRATEGY adios_nc4_should_buffer(
         struct adios_file_struct *fd,
         struct adios_method_struct *method)
 {
@@ -1416,7 +1416,7 @@ enum ADIOS_FLAG adios_nc4_should_buffer(
 
     free(name);
 
-    return adios_flag_no;
+    return no_buffering;
 }
 
 int adios_nc4_open(
@@ -1468,7 +1468,7 @@ int adios_nc4_open(
 void adios_nc4_write(
         struct adios_file_struct *fd,
         struct adios_var_struct *v,
-        void *data,
+        const void *data,
         struct adios_method_struct *method)
 {
     struct open_file *of=NULL;
@@ -1563,6 +1563,12 @@ void adios_nc4_read(
     }
 }
 
+void adios_nc4_buffer_overflow (struct adios_file_struct * fd, 
+                                struct adios_method_struct * method)
+{
+    // this never happens without shared buffering
+}
+
 void adios_nc4_close(
         struct adios_file_struct *fd,
         struct adios_method_struct *method)
