@@ -29,7 +29,6 @@
 #define FORWARD 0
 #define REVERSE 1
 
-extern struct adios_transport_struct * adios_transports;
 static int varcnt=0;
 static char io_method[16]; //the IO method for data output
 static char io_parameters[256]; //the IO method parameters
@@ -651,7 +650,7 @@ static int do_write (int64_t fd_p, const char * name, void * var)
 // temporary solution for compiling error
 static int declare_group (int64_t * id, const char * name
                         ,const char * time_index
-                        ,enum ADIOS_FLAG stats
+                        ,enum ADIOS_STATISTICS_FLAG stats
                         )
 {
     int ret;
@@ -746,7 +745,8 @@ static void output_vars(struct aggr_var_struct *vars, int varcnt, struct
         vars=vars->next;
     }
     //close the file
-    common_adios_close(md->fpr);
+    struct adios_file_struct * mdf = (struct adios_file_struct *) md->fpr;
+    common_adios_close(mdf);
 }
 
 
@@ -759,7 +759,7 @@ static void define_iogroup(char *group_name)
     grp_name=(char *)malloc(len);
     memset(grp_name, 0x00, len);
     sprintf(grp_name, "agg_%s",group_name);
-    declare_group (&grp,grp_name, "", adios_flag_yes);
+    declare_group (&grp,grp_name, "", adios_stat_default);
     select_method (grp, io_method,io_parameters,"");
     grpflag=1;
 }
@@ -905,8 +905,8 @@ int adios_var_merge_open (struct adios_file_struct * fd
     return 1;
 }
 
-enum ADIOS_FLAG adios_var_merge_should_buffer (struct adios_file_struct * fd
-                                         ,struct adios_method_struct * method)
+enum BUFFERING_STRATEGY adios_var_merge_should_buffer (struct adios_file_struct * fd
+                                                      ,struct adios_method_struct * method)
 {
 
     switch (fd->mode)
@@ -926,12 +926,12 @@ enum ADIOS_FLAG adios_var_merge_should_buffer (struct adios_file_struct * fd
         default:
         {
             adios_error (err_invalid_file_mode, "VAR_MERGE method: Unknown file mode requested: %d\n", fd->mode);
-            return adios_flag_no;
+            return no_buffering;
         }
     }
 
     //this method handles its own buffering
-    return adios_flag_no;
+    return no_buffering;
 }
 
 #if 0
@@ -1024,25 +1024,25 @@ void adios_var_merge_write (struct adios_file_struct * fd
             dim = get_value_for_dim (&d->dimension);
             ldims[dims_count]=dim;
             if(dims_count==0)
-                sprintf(vars->dimensions,"%llu", dim);
+                sprintf(vars->dimensions,"%" PRIu64 , dim);
             else
-                sprintf(vars->dimensions,"%s,%llu",vars->dimensions, dim);
+                sprintf(vars->dimensions,"%s,%" PRIu64 ,vars->dimensions, dim);
 
             //global dimension
             dim = get_value_for_dim (&d->global_dimension);
             gdims[dims_count]=dim;
             if(dims_count==0)
-                sprintf(vars->global_dimensions,"%llu", dim);
+                sprintf(vars->global_dimensions,"%" PRIu64 , dim);
             else
-                sprintf(vars->global_dimensions,"%s,%llu",vars->global_dimensions, dim);
+                sprintf(vars->global_dimensions,"%s,%" PRIu64 ,vars->global_dimensions, dim);
 
             //local offsets
             dim = get_value_for_dim (&d->local_offset);
             offsets[dims_count]=dim;
             if(dims_count==0)
-                sprintf(vars->local_offsets,"%llu", dim);
+                sprintf(vars->local_offsets,"%" PRIu64 , dim);
             else
-                sprintf(vars->local_offsets,"%s,%llu",vars->local_offsets, dim);
+                sprintf(vars->local_offsets,"%s,%" PRIu64 ,vars->local_offsets, dim);
 
             dims_count++;
             d=d->next;
@@ -1196,6 +1196,16 @@ void release_resource()
     }
 }
 
+void adios_var_merge_buffer_overflow (struct adios_file_struct * fd, 
+                                      struct adios_method_struct * method)
+{
+    struct adios_MPI_data_struct * md = (struct adios_MPI_data_struct *)
+                                                 method->method_data;
+    log_error ("rank %d: VAR_MERGE method only works with complete buffering of data between adios_open() "
+               "and adios_close(). Variables that do not fit into the buffer will not be "
+               "written by this method to file %s\n", md->rank, fd->name);
+}
+
 void adios_var_merge_close (struct adios_file_struct * fd
                      ,struct adios_method_struct * method
                      )
@@ -1433,9 +1443,9 @@ static uint64_t do_spatial_aggr(int level, int *procs, int ndims, uint64_t *ldim
 
             for(i=0;i<ndims;i++) {
                 if(i==0)
-                    sprintf(new_ldims, "%llu", gdims[i]);
+                    sprintf(new_ldims, "%" PRIu64 , gdims[i]);
                 else
-                    sprintf(new_ldims, "%s,%llu", new_ldims, gdims[i]);
+                    sprintf(new_ldims, "%s,%" PRIu64 , new_ldims, gdims[i]);
             }
 
             //aggregate the chunks
