@@ -19,7 +19,7 @@
 #define DEBUG
 
 //! Debug printing verbosity
-#define DBG_LEVEL   DBG_DEBUG
+#define DBG_LEVEL   DBG_MESSAGE
 
 // New debug messaging state. There is no sense of a "level" for debugging. Each of these define the
 // purpose of the messages and is enabled/disabled per file
@@ -46,23 +46,37 @@
 
 #define p_test_failed(fmt, args...)                             \
     do {                                                  \
-         printf("%s " fmt, DBG_TEST_FAILED_STR,  ##args);  \
+	 fprintf(stderr, "%s "fmt, DBG_TEST_FAILED_STR,  ##args);	\
          fflush(stdout);  											\
     } while(0)
 
 #define p_test_passed(fmt, args...)                             \
+    do {if(test_verbose){					   \
+         fprintf(stderr, "%s "fmt, DBG_TEST_PASSED_STR,  ##args);  \
+         fflush(stdout);  											\
+	}} while(0)
+
+#define test_failed(prog_name, rank)                             \
     do {                                                  \
-         printf("%s " fmt, DBG_TEST_PASSED_STR,  ##args);  \
+	 fprintf(stdout, "%s\t\tProgram name: %s\tRank: %d\n", DBG_TEST_FAILED_STR, prog_name, rank);	\
          fflush(stdout);  											\
     } while(0)
 
+#define test_passed(prog_name, rank)                             \
+    do {                                                  \
+         fprintf(stdout, "%s\t\tProgram name: %s\tRank: %d\n", DBG_TEST_PASSED_STR, prog_name, rank);  \
+         fflush(stdout);  											\
+    } while(0)
+
+
+
 
 
 //! @todo do something like that but smarter without unnecessary copying
 #define p_error(fmt, args...)                             				\
     do {                                                                \
         if((DBG_ERROR) <= DBG_LEVEL) {                                  \
-            printf("%s(%d) %s:%s:%d: " fmt, DBG_ERROR_STR, (DBG_ERROR), __FILE__, __FUNCTION__, __LINE__, ##args);   \
+            fprintf(stderr, "%s(%d) %s:%s:%d: " fmt, DBG_ERROR_STR, (DBG_ERROR), __FILE__, __FUNCTION__, __LINE__, ##args);   \
             fflush(stdout);  											\
         }                                                               \
     } while(0)
@@ -71,7 +85,7 @@
 #define p_warn(fmt, args...) \
 	do {                                                                \
         if((DBG_WARNING) <= DBG_LEVEL) {                                      \
-        	printf("%s(%d) %s:%s:%d: " fmt, DBG_WARN_STR, (DBG_ERROR), __FILE__, __FUNCTION__, __LINE__, ##args);   \
+        	fprintf(stderr, "%s(%d) %s:%s:%d: " fmt, DBG_WARN_STR, (DBG_ERROR), __FILE__, __FUNCTION__, __LINE__, ##args);   \
             fflush(stdout);												\
         }                                                               \
     } while(0)
@@ -79,7 +93,7 @@
 #define p_info(fmt, args...) \
 	do {                                                                \
         if((DBG_INFO) <= DBG_LEVEL) {                                      \
-        	printf("%s(%d) %s:%s:%d: " fmt, DBG_INFO_STR, (DBG_ERROR), __FILE__, __FUNCTION__, __LINE__, ##args);   \
+        	fprintf(stderr, "%s(%d) %s:%s:%d: " fmt, DBG_INFO_STR, (DBG_ERROR), __FILE__, __FUNCTION__, __LINE__, ##args);   \
             fflush(stdout);												\
         }                                                               \
     } while(0)
@@ -87,7 +101,7 @@
 #define p_debug(fmt, args...) \
 	do {                                                                \
         if((DBG_DEBUG) <= DBG_LEVEL) {                                      \
-        	printf("%s(%d) %s:%s:%d: " fmt, DBG_DEBUG_STR, (DBG_ERROR), __FILE__, __FUNCTION__, __LINE__, ##args);   \
+        	fprintf(stderr, "%s(%d) %s:%s:%d: " fmt, DBG_DEBUG_STR, (DBG_ERROR), __FILE__, __FUNCTION__, __LINE__, ##args);   \
             fflush(stdout);												\
         }                                                               \
     } while(0)
@@ -109,14 +123,16 @@
  *
  * The macro causes to return DIAG_ERR if getting options returned errors
  */
-#define GET_ENTRY_OPTIONS(adios_opts, help_string) \
+static int test_verbose = 0;
+
+#define GET_ENTRY_OPTIONS(adios_opts, help_string)	\
 	if (1 == argc){ \
 		p_error("See '-h' for options. At least transport param needs to be specified. Quitting ...\n"); \
 		return DIAG_ERR; \
 	} \
 	do { \
 		int show_help = 0; \
-		if( DIAG_OK != get_options(&adios_opts, argc, argv, &show_help) ){ \
+		if( DIAG_OK != get_options(&adios_opts, argc, argv, &show_help, &test_verbose) ){ \
 			p_error("Got from get_options(). Quitting ...\n."); \
 			return DIAG_ERR; \
 		} \
@@ -223,7 +239,7 @@
 #define TEST_INT_EQUAL(value_ref, value, err_count, test_res) \
 	if (value != value_ref ){ \
 		test_res = TEST_FAILED; \
-		p_test_failed("(expected=%d, got=%d)\n", value_ref, value); \
+		p_test_failed("("#value_ref" != "#value"  -> expected=%d, got=%d)\n", value_ref, value); \
 		err_count++; \
 	}
 
@@ -238,7 +254,7 @@
 #define TEST_LONG_EQUAL(value_ref, value, err_count, test_res) \
 	if (value != value_ref ){ \
 		test_res = TEST_FAILED; \
-		p_test_failed("(expected=%" PRIu64 ", got=%" PRIu64 ")\n", value_ref, value); \
+		p_test_failed("("#value_ref" != "#value"  -> expected=%" PRIu64 ", got=%" PRIu64 ")\n", value_ref, value); \
 		err_count++; \
 	}
 
@@ -253,7 +269,7 @@
 #define TEST_DOUBLE_EQUAL(value_ref, value, err_count, test_res) \
 	if (value != value_ref ){ \
 		test_res = TEST_FAILED; \
-		p_test_failed("(expected=%0.2f, got=%0.2f)\n", value_ref, value); \
+		p_test_failed("("#value_ref" != "#value"  -> expected=%g, got=%g)\n", value_ref, value); \
 		err_count++; \
 	}
 
