@@ -1,7 +1,7 @@
 #!/bin/bash
 #
 # Test if adios aggregates data by color properly.
-# Uses the example code from examples/C/global-array/adios_global_aggregate_by_color
+# Uses the example code from programs/examples/global_array/global_array_aggregate_by_color_C
 #
 # Environment variables set by caller:
 # MPIRUN        Run command
@@ -20,14 +20,14 @@ if [ $MAXPROCS -lt $PROCS ]; then
 fi
 
 # copy codes and inputs to . 
-cp $TRUNKDIR/examples/C/global-array/adios_global_aggregate_by_color .
+cp $SRCDIR/programs/examples/global_array/global_array_aggregate_by_color_C .
 
 echo "Run C adios_global_aggregate_by_color"
-$MPIRUN $NP_MPIRUN $PROCS $EXEOPT ./adios_global_aggregate_by_color
+$MPIRUN $NP_MPIRUN $PROCS $EXEOPT ./global_array_aggregate_by_color_C
 EX=$?
-if [ ! -f adios_global_aggregate_by_color.bp ] \
-|| [! -f adios_global_aggregate_by_color.bp.dir/adios_global_aggregate_by_color.bp.0 ] \
-|| [! -f adios_global_aggregate_by_color.bp.dir/adios_global_aggregate_by_color.bp.1 ]; then
-    echo "ERROR: adios_global_aggregate_by_color failed. No BP file is created. Exit code=$EX"
+if [ ! -f global_array_aggregate_by_color_C.bp ] \
+|| [! -f global_array_aggregate_by_color_C.bp.dir/global_array_aggregate_by_color_C.bp.0 ] \
+|| [! -f global_array_aggregate_by_color_C.bp.dir/global_array_aggregate_by_color_C.bp.1 ]; then
+    echo "ERROR: adios_global_aggregate_by_color failed. No BP file or subfiles are created. Exit code=$EX"
     exit 1
 fi
