@@ -34,6 +34,7 @@
 
 // User arguments
 int verbose=0;   // 1: print summary, 2: print indexes 3: print working info
+int removeZNTB=0; // 1: remove non-transformed,zero blocks from a transformed variable
 int nthreads=1;  // Number of threads to use (main counts as 1 thread)
 char * filename; // process 'filename'.dir/'filename'.NNN subfiles and 
                  //   generate metadata file 'filename'
@@ -43,6 +44,7 @@ struct option options[] = {
     {"help",                 no_argument,          NULL,    'h'},
     {"verbose",              no_argument,          NULL,    'v'},
     {"nsubfiles",            required_argument,    NULL,    'n'},
+    {"zero-blocks",          no_argument,          NULL,    'z'},
 #if HAVE_PTHREAD
     {"nthreads",             required_argument,    NULL,    't'},
 #endif
@@ -50,9 +52,9 @@ struct option options[] = {
 };
 
 #if HAVE_PTHREAD
-static const char *optstring = "hvn:t:";
+static const char *optstring = "hvzn:t:";
 #else
-static const char *optstring = "hvn:";
+static const char *optstring = "hvzn:";
 #endif
 
 // help function
@@ -74,6 +76,9 @@ void display_help() {
             "  --help      | -h       Print this help.\n"
             "  --verbose   | -v       Print log about what this program is doing.\n"
             "                           Use multiple -v to increase logging level.\n"
+            "Other options\n"
+            "  --zero-blocks | -z     Remove all zero sized data blocks from index\n"
+            "\n"
             "Typical use: bpmeta -t 16 -n 1024 mydata.bp\n"
            );
 }
@@ -90,6 +95,7 @@ int get_nsubfiles (char *filename);
 void print_pg_index ( int tid, struct adios_index_process_group_struct_v1 * pg_root);
 void print_variable_index (int tid, struct adios_index_var_struct_v1 * vars_root);
 void print_attribute_index (int tid,  struct adios_index_attribute_struct_v1 * attrs_root);
+void remove_zero_blocks (int tid, struct adios_index_var_struct_v1 ** vars_root, int idx);
 
 #if HAVE_PTHREAD
 struct thread_args 
@@ -139,6 +145,10 @@ int main (int argc, char ** argv)
                 verbose++;
                 break;
 
+            case 'z':
+                removeZNTB=1;
+                break;
+
             default:
                 printf("Unrecognized argument: %s\n", optarg);
                 break;
@@ -418,7 +428,11 @@ int process_subfiles (int tid, int startidx, int endidx)
         print_pg_index (tid, new_pg_root);
 
         adios_posix_read_vars_index (b[idx]);
-        adios_parse_vars_index_v1 (b[idx], &new_vars_root, NULL, NULL);
+        adios_parse_vars_index_v1 (b[idx], &new_vars_root, NULL, NULL);\
+        if (removeZNTB)
+        {
+            remove_zero_blocks(tid, &new_vars_root, idx);
+        }
         print_variable_index (tid, new_vars_root);
 
         if (idx == 0)
@@ -662,6 +676,130 @@ void print_variable_index (int tid, struct adios_index_var_struct_v1 * vars_root
     }
 }
 
+int is_zero_block(struct adios_index_characteristic_struct_v1 * characteristic)
+{
+    int retval = 0;
+    if (characteristic->dims.count > 0)
+    {
+        int j;
+        retval = 1; // assume zero block and negate if not
+        for (j = 0; j < characteristic->dims.count; j++)
+        {
+            if (characteristic->dims.dims [j * 3 + 0] != 0)
+            {
+                retval = 0;
+            }
+        }
+    }
+    return retval;
+}
+
+/* Remove zero size data blocks from array variables  */
+void remove_zero_blocks (int tid, struct adios_index_var_struct_v1 ** vars_root, int idx)
+{
+    unsigned int nvars=0;
+    if (verbose>1) {
+        //printf (DIVIDER);
+        printf ("Thread %d: Look for non-transformed zero blocks in variables with transformation:\n", tid);
+    }
+    struct adios_index_var_struct_v1 * var_prev = NULL;
+    struct adios_index_var_struct_v1 * var = *vars_root;
+    while (var)
+    {
+        int nZB=0; // ZNTB = Zero and Non-Transformed Block, which we want to remove
+        int first_good_block=-1;
+        int is_transformed;
+
+        /*
+         * First, check if the variable has zero blocks and also has transformed blocks
+         */
+        uint64_t i;
+        for (i = 0; i < var->characteristics_count; i++)
+        {
+            if (is_zero_block(&var->characteristics[i]))
+            {
+                ++nZB;
+            }
+            if (var->characteristics[i].transform.transform_type != adios_transform_none)
+            {
+                is_transformed = 1;
+            }
+        }
+
+        if (nZB > 0)
+        {
+            char name[256];
+            if (!var->var_path || strlen(var->var_path) == 0)
+            {
+                sprintf (name, "%s", var->var_name);
+            }
+            else
+            {
+                sprintf (name, "%s/%s", var->var_path, var->var_name);
+            }
+            printf ("Thread %d: *** Variable %s has %d ZERO BLOCKS among %" PRIu64 " blocks in subfile %d ***\n",
+                    tid, name, nZB, var->characteristics_count, idx);
+        }
+
+        /*
+         * Remove the zero blocks that are not-transformed from the lists
+         * if there is any transformed blocks
+         */
+        if (nZB == var->characteristics_count)
+        {
+            // All blocks in this list is zero, remove the whole variable
+            printf ("Thread %d: Remove entire variable from subfile index %d\n", tid, idx);
+            if (var_prev == NULL)
+            {
+                // vars_root need to be changed here
+                vars_root = &(var->next);
+            }
+            else
+            {
+                var_prev->next = var->next;
+            }
+            // This variable index is not freed so its a leak
+        }
+        else if (nZB > 0)
+        {
+            printf ("Thread %d: Remove zero, non-transformed blocks from subfile index %d\n", tid, idx);
+            struct adios_index_characteristic_struct_v1 * old_ch = var->characteristics;
+            struct adios_index_characteristic_struct_v1 * new_ch =
+                    (struct adios_index_characteristic_struct_v1 *)
+                    malloc ((var->characteristics_count - nZB) *
+                            sizeof(struct adios_index_characteristic_struct_v1));
+            uint64_t oldidx;
+            uint64_t newidx = 0;
+            for (oldidx = 0; oldidx < var->characteristics_count; oldidx++)
+            {
+                if (!is_zero_block(&old_ch[oldidx]))
+                {
+                    // Retain this block in index
+                    memcpy(&new_ch[newidx], &old_ch[oldidx],
+                            sizeof(struct adios_index_characteristic_struct_v1));
+                    new_ch[newidx].value = old_ch[oldidx].value;
+                    new_ch[newidx].stats = old_ch[oldidx].stats;
+                    new_ch[newidx].transform.transform_metadata = old_ch[oldidx].transform.transform_metadata;
+                    ++newidx;
+                }
+            }
+            var->characteristics = new_ch;
+            var->characteristics_count = newidx;
+            const char * typestr = adios_type_to_string_int (var->type);
+            printf ("Thread %d: %" PRIu64 " blocks kept in index. ", tid, newidx);
+            if (is_transformed)
+            {
+                var->type = adios_byte;
+                printf ("Type changed from %s to byte", typestr);
+            }
+            printf("\n");
+        }
+        var_prev = var;
+        var = var->next;
+        nvars++;
+    }
+}
+
 void print_attribute_index (int tid, struct adios_index_attribute_struct_v1 * attrs_root)
 {
     unsigned int nattrs=0;
