@@ -1,6 +1,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 #include "public/adios.h"
 #include "public/adios_read.h"
 #include <iapi.h>
@@ -280,7 +281,7 @@ void onSelection(int rank, ADIOS_FILE* f, ADIOS_VARINFO* v, int timestep, char*
       sum_nb += nb; sum_nk += nk, sum_no += no;
 
       adios_allocate_buffer (ADIOS_BUFFER_ALLOC_NOW, 500); // +5MB for extra room in buffer
-      adios_declare_group (&gAdios_group, gGroupNameFastbitIdx, "", adios_flag_yes);
+      adios_declare_group (&gAdios_group, gGroupNameFastbitIdx, "", adios_stat_default);
       adios_select_method (gAdios_group, "MPI", "", "");
 
       adios_open (&gAdios_write_file, gGroupNameFastbitIdx, gIdxFileName, "w", MPI_COMM_WORLD);
@@ -321,7 +322,7 @@ void onMultiBlock(int rank, ADIOS_FILE* f, ADIOS_VARINFO* v, int timestep, int b
   int i=0;
   
   char selName[100];
-  sprintf(selName, "block-%d", blockStart, blockEnd);
+  sprintf(selName, "block-%d..%d", blockStart, blockEnd);
 
   uint64_t blockSizeArray[blockEnd-blockStart];
 
@@ -424,7 +425,7 @@ void processData(void* data, uint64_t dataCount, int rank, int timestep, char* s
       defineFastbitVar(1, keyVarName, &var_ids_key, adios_double, &nk, 0, 0);
       defineFastbitVar(1, offsetName, &var_ids_offset, adios_long, &no, 0, 0); 
 
-      printf("bms[0] = %" PRIu64 ", bms[1]=%" PRIu64 " \n", bms[0], bms[1]);
+      printf("bms[0] = %" PRIu32 ", bms[1]=%" PRIu32 " \n", bms[0], bms[1]);
       //var_ids_bms = defineAdiosVar(bmsVarName, adios_unsigned_integer, nb, 0, 0);
       //var_ids_key = defineAdiosVar(keyVarName, adios_double, nk, 0, 0);
       //var_ids_offset = defineAdiosVar(offsetName, adios_long, no, 0, 0);
@@ -790,14 +791,14 @@ int main (int argc, char** argv)
   
   /*
   adios_allocate_buffer (ADIOS_BUFFER_ALLOC_NOW, (f->file_size)*2/1048576 + 5); // +5MB for extra room in buffer
-  adios_declare_group (&gAdios_group, gGroupNameFastbitIdx, "", adios_flag_yes);
+  adios_declare_group (&gAdios_group, gGroupNameFastbitIdx, "", adios_stat_default);
   adios_select_method (gAdios_group, "MPI", "", "");
   */
   gIdxFileName = fastbit_adios_util_getFastbitIndexFileName(argv[1]);
   unlink(gIdxFileName);
 
       //adios_allocate_buffer (ADIOS_BUFFER_ALLOC_NOW, 500); // +5MB for extra room in buffer
-      adios_declare_group (&gAdios_group, gGroupNameFastbitIdx, "", adios_flag_yes);
+      adios_declare_group (&gAdios_group, gGroupNameFastbitIdx, "", adios_stat_default);
       adios_select_method (gAdios_group, "MPI", "", "");
 
       adios_open (&gAdios_write_file, gGroupNameFastbitIdx, gIdxFileName, "w", MPI_COMM_WORLD);
