@@ -11,7 +11,7 @@ import getopt, sys
 
 def usage():
     print "USAGE: %s filename" % sys.argv[0]
-    
+
 def main():
     fname = ""
     if len(sys.argv) < 2:
@@ -28,11 +28,11 @@ def main():
     print "  %-18s %d" % ("file size:", f.file_size)
     print "  %-18s %d" % ("bp version:", f.version)
     print ""
-    
+
     for k in sorted(f.var.keys()):
         v = f.var[k]
-        print "  %-17s  %-12s  %d*%s" % (np.typename(np.sctype2char(v.type)), v.name, v.nsteps, v.dims)
-            
+        print "  %-17s  %-12s  %d*%s" % (np.typename(np.sctype2char(v.dtype)), v.name, v.nsteps, v.dims)
+
 
 if __name__ == "__main__":
     main()
