@@ -10,7 +10,7 @@ import numpy as np
 import matplotlib.pyplot as plt
 
 ## Writing
-print "\n>>> Writing ...\n"
+print("\n>>> Writing ...\n")
 
 ad.init("config.xml")
 fd = ad.open("temperature", "adios_test.bp", "w")
@@ -18,7 +18,7 @@ fd = ad.open("temperature", "adios_test.bp", "w")
 NX = 10
 size = 2
 groupsize =  4 + 4 + 8 * size * NX
-t = np.array(range(NX*size), dtype=np.float64)
+t = np.array(list(range(NX*size)), dtype=np.float64)
 tt = t.reshape((size, NX))
 ad.set_group_size(fd, groupsize)
 ad.write_int(fd, "NX", NX)
@@ -29,28 +29,27 @@ ad.close(fd)
 ad.finalize()
 
 ## Reading
-print "\n>>> Reading ...\n"
+print("\n>>> Reading ...\n")
 
 f = ad.file("adios_test.bp")
 f.printself()
 
-v = f.var['temperature']
+v = f.vars['temperature']
 v.printself()
 
 val = v.read()
-print val
+print(val)
 assert ((tt == val).all())
 f.close()
 
 ## Testing
-print "\n>>> Test utility functions ...\n"
+print("\n>>> Test utility functions ...\n")
 
-print "bpls:\n", ad.bpls('adios_test.bp')
-print "readvar:\n", ad.readvar("adios_test.bp", "temperature")
+print("bpls:\n", ad.bpls('adios_test.bp'))
+print("readvar:\n", ad.readvar("adios_test.bp", "temperature"))
 
 plt.imshow(val)
 plt.colorbar()
 plt.show()
 
-print "\n>>> Done.\n"
-
+print("\n>>> Done.\n")
